"""redis-fs: A unified file-system-like storage API with Redis and local filesystem backends."""

from redis_fs.redis_fs import RedisFs
from redis_fs.exceptions import (
    RedisFsError,
    ConfigurationError,
    ConnectionError,
    NotFoundError,
    SyncError,
)

__version__ = "0.1.0"
__all__ = [
    "RedisFs",
    "RedisFsError",
    "ConfigurationError",
    "ConnectionError",
    "NotFoundError",
    "SyncError",
    "__version__",
]
